@@ -25,18 +25,25 @@ from typing import (
     # overload,
     # cast,
     Optional,
+    TypeVar, Generic)
+
+from wechaty_puppet import (  # type: ignore
+    get_logger,
+    Puppet
 )
-from wechaty_puppet import get_logger   # type: ignore
+
+from wechaty.exceptions import WechatyAccessoryBindingError
 
 # pylint:disable=R0401
 if TYPE_CHECKING:
-    from wechaty_puppet import Puppet   # type: ignore
     from .wechaty import Wechaty
 
 log = get_logger('Accessory')
 
+PayloadType = TypeVar('PayloadType')
 
-class Accessory:
+
+class Accessory(Generic[PayloadType]):
     """
     Translate the function from TypeScript to Python
     See: https://github.com/wechaty/wechaty/blob/master/src/accessory.ts
@@ -45,18 +52,70 @@ class Accessory:
     _puppet: Optional[Puppet] = None
     _wechaty: Optional[Wechaty] = None
 
+    abstract: bool = True
+
+    def __init__(self):
+        if self.abstract:
+            raise WechatyAccessoryBindingError(
+                'Do not instantiate class {cls} directly, sse with bot.{cls} instead. '
+                'See https://github.com/Chatie/wechaty/issues/1217'.format(
+                    cls=type(self).__name__
+                )
+            )
+
+        # if self.puppet is None:
+        #     raise WechatyAccessoryBindingError(
+        #         '{} class can not be instantiated without a puppet!'.format(
+        #             type(self).__name__
+        #         )
+        #     )
+
+        self._payload: Optional[PayloadType] = None
+
+    @property
+    def payload(self) -> PayloadType:
+        """
+        get the payload object as a property
+        :return:
+        """
+        if self._payload is None:
+            raise ValueError(
+                'should ready()<sync> the {} payload before get it, '
+                'please call the <ready()> method'.format(
+                    type(self).__name__
+                )
+            )
+        return self._payload
+
+    @payload.setter
+    def payload(self, value: PayloadType):
+        """
+        :param value:
+        :return:
+        """
+        if self._payload:
+            raise WechatyAccessoryBindingError('Cannot set payload more than once.')
+        self._payload = value
+
+    def is_ready(self) -> bool:
+        """
+        check if payload is ready
+        :return:
+        """
+        return self._puppet is not None and self._payload is not None
+
     @classmethod
     def set_puppet(cls, new_puppet: Puppet):
         """doc"""
         if cls._puppet is not None:
-            raise AttributeError('can not set twice')
+            raise AttributeError('can not set _puppet twice')
         cls._puppet = new_puppet
 
     @classmethod
     def set_wechaty(cls, new_wechaty: Wechaty):
         """doc"""
         if cls._wechaty is not None:
-            raise AttributeError('can not set twice')
+            raise AttributeError('can not set _wechaty twice')
         cls._wechaty = new_wechaty
 
     @classmethod
