@@ -440,9 +440,17 @@ class Message(Accessory[MessagePayload]):
     def date(self) -> datetime:
         """
         Message sent date
+        Python2.7: https://docs.python.org/2.7/library/datetime.html#datetime.datetime
+        Python3+ ：https://docs.python.org/3.7/library/datetime.html#datetime.datetime
+        for datetime.fromtimestamp. It’s common for this to be restricted to years from 1970 through 2038. 
+        2145888000 is 2038-01-01 00:00:00 UTC for second
+        2145888000 is 1970-01-26 04:04:48 UTC for millisecond
         :return:
         """
-        time = datetime.fromtimestamp(self.payload.time_stamp)
+        if self.payload.timestamp > 2145888000:
+            time = datetime.fromtimestamp(self.payload.timestamp/1000)
+        else:
+            time = datetime.fromtimestamp(self.payload.timestamp)
         return time
 
     def age(self) -> int:
