@@ -33,9 +33,10 @@ from typing import (
     TYPE_CHECKING
 )
 import json
-from pyee import AsyncIOEventEmitter    # type: ignore
+from pyee import AsyncIOEventEmitter  # type: ignore
 # from wechaty_puppet import RoomMemberPayload
-from wechaty_puppet import (    # type: ignore
+from wechaty.exceptions import WechatyOperationError, WechatyPayloadError
+from wechaty_puppet import (  # type: ignore
     FileBox,
     RoomQueryFilter,
     RoomMemberQueryFilter,
@@ -46,7 +47,6 @@ from wechaty_puppet import (    # type: ignore
 from ..accessory import Accessory
 
 if TYPE_CHECKING:
-
     from .contact import Contact
     from .url_link import UrlLink
     from .mini_program import MiniProgram
@@ -55,7 +55,7 @@ if TYPE_CHECKING:
 log = get_logger('Room')
 
 
-class Room(Accessory):
+class Room(Accessory[RoomPayload]):
     """
     All wechat rooms(groups) will be encapsulated as a Room.
     """
@@ -63,15 +63,9 @@ class Room(Accessory):
 
     def __init__(self, room_id: str) -> None:
         """docs"""
+        super().__init__()
+
         self.room_id = room_id
-        self.payload: Optional[RoomPayload] = None
-
-        # if self.__class__ is Room:
-        #     raise Exception('Room class can not be instanciated directly!')
-
-        if self.puppet is None:
-            raise Exception(
-                'Room class can not be instanciated without a puppet!')
 
     _event_stream: AsyncIOEventEmitter = AsyncIOEventEmitter()
 
@@ -94,29 +88,29 @@ class Room(Accessory):
         create room instance
         """
         if not hasattr(contacts, '__len__'):
-            raise Exception('contacts should be list type')
+            raise WechatyOperationError('contacts should be list type')
         if len(contacts) < 2:
-            raise Exception(
+            raise WechatyOperationError(
                 'contactList need at least 2 contact to create a new room'
             )
 
         log.info(
-            'Room create <%s, %s>',
+            'Room create <%s - %s>',
             ','.join([contact.contact_id for contact in contacts]),
             topic
         )
 
         try:
             contact_ids = list(map(lambda x: x.contact_id, contacts))
-            room_id = await cls.get_puppet().\
+            room_id = await cls.get_puppet(). \
                 room_create(contact_ids=contact_ids, topic=topic)
-            return cls.load(room_id=room_id)
+            room = cls.load(room_id=room_id)
+            await room.ready()
+            return room
         except Exception as exception:
-            log.error(
-                'Room create error <%s>',
-                str(exception.args)
-            )
-            raise Exception('Room create error')
+            message = 'Room create error <%s>' % str(exception.args)
+            log.error(message)
+            raise WechatyOperationError(message)
 
     @classmethod
     async def find_all(cls,
@@ -202,15 +196,13 @@ class Room(Accessory):
         """
         dynamic load room instance
         """
-        if room_id in cls._pool:
-            room = cls._pool.get(room_id)
-            if room is None:
-                raise Exception('room not found')
+        room = cls._pool.get(room_id)
+        if room is not None:
             return room
 
-        new_room = cls(room_id)
-        cls._pool[room_id] = new_room
-        return new_room
+        room = cls(room_id)
+        cls._pool[room_id] = room
+        return room
 
     def __str__(self):
         """
@@ -222,13 +214,7 @@ class Room(Accessory):
         if self.payload.topic is None:
             return 'loading ...'
 
-        return 'Room <%s>' % self.payload.topic
-
-    def is_ready(self) -> bool:
-        """
-        check if room's payload is ready
-        """
-        return self.payload is not None
+        return 'Room <%s - %s>' % (self.room_id, self.payload.topic)
 
     async def ready(self, force_sync=False):
         """
@@ -247,7 +233,7 @@ class Room(Accessory):
         self.payload = await self.puppet.room_payload(self.room_id)
 
         if self.payload is None:
-            raise Exception('Room Payload can"t be ready')
+            raise WechatyPayloadError('Room Payload can"t be ready')
 
         member_ids = await self.puppet.room_members(self.room_id)
 
@@ -306,7 +292,7 @@ class Room(Accessory):
                 mini_program=some_thing.payload
             )
         else:
-            raise Exception('arg unsupported: ', some_thing)
+            raise WechatyOperationError('arg unsupported: ', some_thing)
 
         if msg_id is not None:
             msg = self.wechaty.Message.load(msg_id)
@@ -341,7 +327,7 @@ class Room(Accessory):
         log.info('Room delete<%s>', contact)
 
         if contact is None or contact.contact_id is None:
-            raise Exception('Contact is none or contact_id not found')
+            raise WechatyOperationError('Contact is none or contact_id not found')
         await self.puppet.room_delete(self.room_id, contact.contact_id)
         # reload the payload
         await self.ready(force_sync=True)
@@ -360,9 +346,7 @@ class Room(Accessory):
         """
         log.info('Room topic (%s)', new_topic)
 
-        if not self.is_ready():
-            log.warning('Room topic() room not ready')
-            raise Exception('Room not ready')
+        await self.ready()
 
         if new_topic is None:
             if self.payload is not None and self.payload.topic is not None:
@@ -441,12 +425,12 @@ class Room(Accessory):
         the result of the function will always return an empty string
         """
         if member is None:
-            raise Exception('member can"t be none')
+            raise WechatyOperationError('member can"t be none')
         room_member_payload = await self.puppet.room_member_payload(
             room_id=self.room_id, contact_id=member.contact_id)
 
         if room_member_payload is not None \
-                and room_member_payload.room_alias is not None:
+            and room_member_payload.room_alias is not None:
             return room_member_payload.room_alias
         return None
 
@@ -484,7 +468,7 @@ class Room(Accessory):
                         if member.name.__contains__(query):
                             member_search_result.append(member)
                         elif member.payload.alias is not None and \
-                                member.payload.alias.__contains__(query):
+                            member.payload.alias.__contains__(query):
                             member_search_result.append(member)
 
                     # get room_alias but hostie-server not support
@@ -498,8 +482,8 @@ class Room(Accessory):
                             member_search_result.append(member)
 
                         elif member.payload.alias is not None and \
-                                member.payload.alias.__contains__(
-                                    query.contact_alias):
+                            member.payload.alias.__contains__(
+                                query.contact_alias):
 
                             member_search_result.append(member)
 
@@ -529,8 +513,7 @@ class Room(Accessory):
         get room owner
         """
         log.info('Room <%s> owner', self)
-        if self.payload is None:
-            raise Exception('Room <%s> payload not found', self)
+        await self.ready()
 
         if self.payload.owner_id is None or self.payload.owner_id == '':
             # raise Exception('Room <%s> payload or payload.owner_id not found')
